/**
 * @file	    _dsr.h
 * @brief		DSR header file
 * @version		1.0 
  
 */


// Notes: * I have defined the variable destination, the array away[] and counter in ScatterWeb.Net.h under struct netheader      
              


#ifndef _DSR_H_
#define _DSR_H_


#include <ScatterWeb.Net.h> 



/**
 * @brief	DSR Route Request Packet Type
 */
#define DSR_REQUEST_PACKET USERDEFINED_PACKET+2

/**
 * @brief	DSR Route Response Packet Type
 */
#define DSR_REPLY_PACKET USERDEFINED_PACKET+3

/**
 * @brief   Data Packet Type
 */
#define DATA_PACKET USERDEFINED_PACKET+4

/**
 * @brief	ACK Packet Type
 */
#define ACK_PACKET USERDEFINED_PACKET+5



/**
 * @brief local broadcast address
 */
#define MY_BROADCAST 0x1E  


#define ARRAYLAENGE 10 





/**
 * @brief	help-array for the storage of the list with knot from dsr-reply were found
 */
 uint8_t help_array[];


/**
 * @brief	help-variable for the storage of the Destination
 */
 netaddr_t copy_dest;
     

//DSR FUNCTION DEFINITION


/**
 * @brief				function to restart Route Discovery Process
 * @param[in]			dest			Destination address
 */
bool Net_sendRequest(netaddr_t dest);

/**
 * @brief				function to send the Request away
 *  @param[in]			dest			Destination address
 * @param[in]			counter			counter for nodes
 * @param[in]			feld[]			list for nodes 
 */
bool handle_Request (netaddr_t dest,uint8_t counter,uint8_t feld []);

/**
 * @brief				function to send the Reply 
 * @param[in]			dest			Destination address
 * @param[in]			counter			counter for nodes
 * @param[in]			feld[]			list for nodes 
 */

bool Net_sendReply(netaddr_t dest,uint8_t counter,uint8_t feld []);

/**
 *  @brief				function to send the Reply further
 *  @param[in]			dest			Destination address
 *  @param[in]			counter			counter for nodes
 *  @param[in]			feld[]			list for nodes 
 */
void handle_Reply (netaddr_t dest,uint8_t counter,uint8_t feld []);

/**
 *  @brief				function to call the Funktion Net_sendRequest
 *  @param[in]			dest			Destination address
 */
bool Route_discovery(netaddr_t dest);
/**
 *  @brief				function to decides if node is destination than Reply else Request
 *  @param[in]			dest			Destination address
 *  @param[in]			counter			counter for nodes
 *  @param[in]			feld[]			list for nodes 
 */
bool Net_sendDecides(netaddr_t dest,uint8_t counter,uint8_t feld []);

/**
 *  @brief				function to send the Data 
 */ 
bool Net_sendData();

/**
 *  @brief				function to send the Data away 
 *  @param[in]			dest			Destination address
 *  @param[in]			*data           pointer for data
 *  @param[in]			feld[]			list for nodes 
 */
bool handle_Data(netaddr_t dest,uint8_t* data,uint8_t feld[]);

/**
 *  @brief				function to send the Ack 
 *  @param[in]			feld[]			list for nodes 
 */
bool Net_sendAck(uint8_t feld[]);

/**
 *  @brief				function to decides 
 *  @param[in]			dest			Destination address
 *  @param[in]			*data            pointer for data
 *  @param[in]			feld[]			list for nodes 
 */ 
bool Decides_data(netaddr_t dest,uint8_t* data,uint8_t feld[]);



void Net_sendArgsInit_1(netpacket_send_args_t* args);


/**
 * @brief Compare network address with this node's address
 * @param[in]	adr					Address to compare with #config_t:id
 * @param[in]	directConnection	Indicates that the address request comes from a directly
 * 									connected source (e.g. serial cable)
 * @return		one of enum netaddr_compareresult
 * In addition the node can be addressed by network and or node id set to zero
 * if the addressing party is directly connected. This will be the case if a
 * directly conntected PC want's to address this node without knowing it's address.
 */
enum netaddr_compareresult Net_compareAddress_1(
	const netaddr_t (*const adr),
	const bool directConnection
);









#endif /*_DSR_H_*/
/** @} */
